@@ -1,13 +1,20 @@
+from sqlalchemy import MetaData
 from sqlalchemy.engine import Connection
+from typing_extensions import Protocol
 
 
-def dialect_dispatch(postgresql=None, sqlite=None):
+class HasMetaData(Protocol):
+    metadata: MetaData
+
+
+def dialect_dispatch(postgresql=None, sqlite=None, mysql=None):
     dispatchers = {
         "postgresql": postgresql,
         "sqlite": sqlite,
+        "mysql": mysql,
     }
 
-    def dispatch(connection: Connection, **kwargs):
+    def dispatch(connection: Connection, *args, **kwargs):
         dialect_name = connection.dialect.name
         if dialect_name == "pmrsqlite":
             dialect_name = "sqlite"
@@ -18,6 +25,6 @@ def dialect_dispatch(postgresql=None, sqlite=None):
                 f"'{dialect_name}' is not yet supported for this operation."
             )
 
-        return dispatcher(connection, **kwargs)
+        return dispatcher(connection, *args, **kwargs)
 
     return dispatch
